@@ -56,7 +56,7 @@
 #define PROGRESS_FORMAT_SIZE 8
 #define MIN_FILENAME_SIZE 5
 #define MIN_MIDDLE_TRUNCATE_SIZE 20
-#define TEMP_NAME "vorbisgain.tmp"
+#define TEMP_NAME "vorbisgain.tmpXXXXXX"
 
 
 /**
@@ -699,6 +699,18 @@ int write_gains(const char *filename, float track_peak, float track_gain,
     strcpy(temp_name, filename);
     strcpy((char *) last_path(temp_name), TEMP_NAME);
 
+#ifdef WIN32
+    temp_name = _mktemp(temp_name);
+#else
+    temp_name = mktemp(temp_name);
+#endif
+
+    if (temp_name == NULL)
+    {
+	fprintf(stderr, _("Couldn't create temporary file for processing.\n"));
+    	goto exit;
+    }
+    
     outfile = fopen(temp_name, "wb");
 
     if (outfile == NULL)
