@@ -34,7 +34,7 @@
 
 
 /* Some version numbers */
-#define VG_VERSION     "0.35"
+#define VG_VERSION     "0.36"
 #define VORBIS_VERSION "1.0"
 
 
@@ -484,7 +484,7 @@ int process_files(FILE_LIST* file_list, SETTINGS* settings)
 static void print_help(void)
 {
     fprintf(stderr, _("VorbisGain v" VG_VERSION " (libvorbis " VORBIS_VERSION ")\n"));
-    fprintf(stderr, _("Copyright (c) 2002-2004 Gian-Carlo Pascutto <gcp@sjeng.org>\n"));
+    fprintf(stderr, _("Copyright (c) 2002-2005 Gian-Carlo Pascutto <gcp@sjeng.org>\n"));
     fprintf(stderr, _("                        and Magnus Holmgren <lear@algonet.se>\n\n"));
     fprintf(stderr, _("Usage: vorbisgain [options] input.ogg [...]\n\n"));
     fprintf(stderr, _("OPTIONS:\n"));
@@ -495,6 +495,7 @@ static void print_help(void)
     fprintf(stderr, _("  -d, --display-only   Display results only. No files are modified\n"));
     fprintf(stderr, _("  -f, --fast           Don't recalculate tagged files\n"));
     fprintf(stderr, _("  -h, --help           Print this help text\n"));
+    fprintf(stderr, _("  -n, --no-progress    Don't show progress, just print results\n"));
     fprintf(stderr, _("  -q, --quiet          Don't print any output (except errors)\n"));
 #ifdef ENABLE_RECURSIVE
     fprintf(stderr, _("  -r, --recursive      Search for files recursivly, each folder as an album\n"));
@@ -520,6 +521,7 @@ const static struct option long_options[] =
     {"display-only", 0, NULL, 'd'},
     {"fast",         0, NULL, 'f'},
     {"help",         0, NULL, 'h'},
+    {"no-progress",  0, NULL, 'n'},
     {"quiet",        0, NULL, 'q'},
 #ifdef ENABLE_RECURSIVE
     {"recursive",    0, NULL, 'r'},
@@ -531,9 +533,9 @@ const static struct option long_options[] =
 
 
 #ifdef ENABLE_RECURSIVE
-#define ARG_STRING "acCdfg:hqrst:v"
+#define ARG_STRING "acCdfg:hnqrst:v"
 #else
-#define ARG_STRING "acCdfg:hqst:v"
+#define ARG_STRING "acCdfg:hnqst:v"
 #endif
 
 
@@ -547,6 +549,7 @@ int main(int argc, char** argv)
     memset(&settings, 0, sizeof(settings));
     settings.first_file = 1;
     settings.album_gain = NO_GAIN;
+    settings.show_progress = 1;
 
 #ifdef WIN32
     /* Is this good enough? Or do we need to consider multi-byte codepages as 
@@ -616,6 +619,10 @@ int main(int argc, char** argv)
             settings.fast = 1;
             break;
 
+	case 'n':
+	  settings.show_progress = 0;
+	  break;
+
         case 'q':
             settings.quiet = 1;
             break;
